/// <reference types="node" />
import { AccessApi, AccessControllerConfig, AccessDeviceConfig } from "unifi-access";
import { AccessControllerOptions } from "./access-options.js";
import { AccessDevice } from "./access-device.js";
import { AccessEvents } from "./access-events.js";
import { AccessLogging } from "./access-types.js";
import { AccessMqtt } from "./access-mqtt.js";
import { AccessPlatform } from "./access-platform.js";
export declare class AccessController {
    private api;
    config: AccessControllerOptions;
    private deviceRemovalQueue;
    readonly configuredDevices: {
        [index: string]: AccessDevice;
    };
    events: AccessEvents;
    private isEnabled;
    private hap;
    logApiErrors: boolean;
    readonly log: AccessLogging;
    mqtt: AccessMqtt | null;
    private name;
    platform: AccessPlatform;
    uda: AccessControllerConfig;
    udaApi: AccessApi;
    private unsupportedDevices;
    constructor(platform: AccessPlatform, accessOptions: AccessControllerOptions);
    private bootstrapController;
    login(): Promise<void>;
    private configureController;
    private addAccessDevice;
    private discoverDevices;
    addHomeKitDevice(device: AccessDeviceConfig): AccessDevice | null;
    private discoverAndSyncAccessories;
    private cleanupDevices;
    removeHomeKitDevice(accessDevice: AccessDevice): void;
    private removeHomeKitAccessories;
    resetControllerConnection(): Promise<void>;
    deviceLookup(deviceId: string): AccessDevice | null;
    getFeatureFloat(option: string): number | undefined;
    getFeatureNumber(option: string): number | undefined;
    hasFeature(option: string, defaultReturnValue?: boolean, device?: AccessControllerConfig | AccessDeviceConfig | null): boolean;
    sleep(sleepTimer: number): Promise<NodeJS.Timeout>;
    private retry;
}
